@@ -195,7 +195,7 @@ void PrintBatteryCharge(GSM_BatteryCharge *BatteryCharge)
 	}
 }
 
-GSM_Error GSM_PlayRingtone(GSM_Ringtone ringtone)
+GSM_Error GSM_PlayRingtone(GSM_Ringtone *ringtone)
 {
 	int 		i;
 	gboolean 		first=TRUE;
@@ -204,11 +204,11 @@ GSM_Error GSM_PlayRingtone(GSM_Ringtone ringtone)
 	signal(SIGINT, interrupt);
 	printf("%s\n", _("Press Ctrl+C to break..."));
 
-	for (i=0;i<ringtone.NoteTone.NrCommands;i++) {
+	for (i = 0; i < ringtone->NoteTone.NrCommands; i++) {
 		if (gshutdown) break;
-		if (ringtone.NoteTone.Commands[i].Type != RING_Note) continue;
-		error=PHONE_RTTLPlayOneNote(gsm,ringtone.NoteTone.Commands[i].Note,first);
-		if (error!=ERR_NONE) return error;
+		if (ringtone->NoteTone.Commands[i].Type != RING_Note) continue;
+		error = PHONE_RTTLPlayOneNote(gsm, ringtone->NoteTone.Commands[i].Note, first);
+		if (error != ERR_NONE) return error;
 		first = FALSE;
 	}
 
@@ -230,139 +230,12 @@ void PlayRingtone(int argc UNUSED, char *argv[])
 
 	GSM_Init(TRUE);
 
-	error=GSM_PlayRingtone(ringtone2);
+	error = GSM_PlayRingtone(&ringtone2);
 	Print_Error(error);
 
 	GSM_Terminate();
 }
 
-/**
- * Get's location from OpenCellID.
- */
-void GetLocation(int argc UNUSED, char *argv[]UNUSED)
-{
-	GSM_File OpenCell;
-	char url[70 + GSM_MAX_MODEL_LENGTH];
-	char *pos;
-	GSM_Error error;
-	GSM_NetworkInfo netinfo;
-	float latitude, longitude;
-	long int mnc, mcc, lac, cellid, nbSamples, range;
-	char *ret, *old_locale = NULL;
-	gboolean failure = FALSE;
-
-	GSM_Init(TRUE);
-
-	/* Get model information */
-	error = GSM_GetNetworkInfo(gsm, &netinfo);
-	Print_Error(error);
-
-	if (netinfo.State == GSM_NoNetwork) {
-		printf_err("%s", _("Not logged to network!\n"));
-		GSM_Terminate();
-		return;
-	}
-
-	/* We need decimal numbers */
-	lac = strtol(netinfo.LAC, NULL, 16);
-	cellid = strtol(netinfo.CID, NULL, 16);
-
-	/* Split code to country and network (beware ncc+nmc without space) */
-	if (sscanf(netinfo.NetworkCode, "%3ld%ld", &mcc, &mnc) != 2) {
-		printf_err("%s", _("Wrong network code from phone!\n"));
-		GSM_Terminate();
-		return;
-	}
-
-	/* Request information from OpenCellID */
-	sprintf(url, "http://www.opencellid.org/cell/get?key=%s&mnc=%ld&mcc=%ld&lac=%ld&cellid=%ld",
-		OPENCELLID_API_KEY,
-		mnc, mcc, lac, cellid);
-
-	OpenCell.Buffer = NULL;
-	OpenCell.Used = 0;
-	error = GSM_ReadHTTPFile(url, &OpenCell);
-	Print_Error(error);
-
-	/* We need to reset numeric locales because we parse floats with . as decimal separator */
-	ret = setlocale(LC_NUMERIC, "C");
-	if (ret != NULL) {
-		old_locale = strdup(ret);
-	}
-
-	/* Parse reply:
-		<?xml version="1.0" encoding="UTF-8"?>
-		<rsp stat="ok">
-		  <cell range="6000" lac="0" lat="54.4910893937777" nbSamples="46" lon="27.9390742994699" cellId="29513" mcc="250" mnc="99"/>
-		</rsp>
-	*/
-	if (strstr(OpenCell.Buffer, "stat=\"ok\"") == NULL) {
-		printf_err("%s", _("Request for information from OpenCellID failed!\n"));
-		failure = TRUE;
-		goto done;
-	}
-	pos = strstr(OpenCell.Buffer, "lat=\"");
-	if (pos == NULL) {
-		printf_err("%s", _("Failed to find latitude in OpenCellID reply!\n"));
-		failure = TRUE;
-		goto done;
-	}
-	if (sscanf(pos, "lat=\"%f\"", &latitude) == 0) {
-		printf_err("%s", _("Failed to parse latitude from OpenCellID reply!\n"));
-		failure = TRUE;
-		goto done;
-	}
-	pos = strstr(OpenCell.Buffer, "lon=\"");
-	if (pos == NULL) {
-		printf_err("%s", _("Failed to find longitude in OpenCellID reply!\n"));
-		failure = TRUE;
-		goto done;
-	}
-	if (sscanf(pos, "lon=\"%f\"", &longitude) == 0) {
-		printf_err("%s", _("Failed to parse longitude from OpenCellID reply!\n"));
-		failure = TRUE;
-		goto done;
-	}
-	pos = strstr(OpenCell.Buffer, "range=\"");
-	if (pos == NULL) {
-		printf_err("%s", _("Failed to find range in OpenCellID reply!\n"));
-		failure = TRUE;
-		goto done;
-	}
-	if (sscanf(pos, "range=\"%ld\"", &range) == 0) {
-		printf_err("%s", _("Failed to parse range from OpenCellID reply!\n"));
-		failure = TRUE;
-		goto done;
-	}
-	pos = strstr(OpenCell.Buffer, "nbSamples=\"");
-	if (pos == NULL) {
-		printf_err("%s", _("Failed to find nbSamples in OpenCellID reply!\n"));
-		failure = TRUE;
-		goto done;
-	}
-	if (sscanf(pos, "nbSamples=\"%ld\"", &nbSamples) == 0) {
-		printf_err("%s", _("Failed to parse nbSamples from OpenCellID reply!\n"));
-		failure = TRUE;
-		goto done;
-	}
-
-done:
-	if (old_locale != NULL) {
-		setlocale(LC_NUMERIC, old_locale);
-		free(old_locale);
-	}
-	if (!failure) {
-		printf(LISTFORMAT "%f\n", _("Latitude"), latitude);
-		printf(LISTFORMAT "%f\n", _("Longitude"), longitude);
-		printf(LISTFORMAT "%ld\n", _("Range"), range);
-		printf(LISTFORMAT "%ld\n", _("Number of samples"), nbSamples);
-	}
-
-	free(OpenCell.Buffer);
-	GSM_Terminate();
-}
-
-
 
 void Identify(int argc, char *argv[])
 {
@@ -1033,7 +906,8 @@ void GetBitmap(int argc, char *argv[])
 {
 	GSM_File		File;
 	GSM_MultiBitmap 	MultiBitmap;
-	int			location=0, Handle, Size;
+	int			location=0, Handle;
+	size_t Size;
 	GSM_AllRingtonesInfo 	Info = {0, NULL};
 	unsigned char		buffer[10];
 	const unsigned char *ringtonename;
