@@ -408,7 +408,7 @@ GSM_Error ATGEN_GetSMSLocation(GSM_StateMachine *s, GSM_SMSMessage *sms, unsigne
 		(*location)--;
 	}
 	smprintf(s, "SMS folder %i & location %i -> ATGEN folder %i & location %i\n",
-			sms->Folder,sms->Location,*folderid,*location);
+			sms->Folder, sms->Location, *folderid, *location);
 
 	/* Set the needed memory type */
 	if (Priv->SIMSMSMemory == AT_AVAILABLE &&
@@ -1534,7 +1534,6 @@ GSM_Error ATGEN_ReplyAddSMSMessage(GSM_Protocol_Message *msg, GSM_StateMachine *
 	GSM_Error error;
 	GSM_Phone_ATGENData *Priv = &s->Phone.Data.Priv.ATGEN;
 	size_t i = 0;
-	int folder = 0;
 
 	switch (Priv->ReplyState) {
 	case AT_Reply_SMSEdit:
@@ -1564,11 +1563,13 @@ GSM_Error ATGEN_ReplyAddSMSMessage(GSM_Protocol_Message *msg, GSM_StateMachine *
 		smprintf(s, "Saved at AT location %i\n",
 				s->Phone.Data.SaveSMSMessage->Location);
 		/* Adjust location */
-		folder = s->Phone.Data.SaveSMSMessage->Folder;
-		ATGEN_SetSMSLocation(s, s->Phone.Data.SaveSMSMessage,
-				(folder / 2), /* We care only about SIM/Phone */
-				s->Phone.Data.SaveSMSMessage->Location);
-		s->Phone.Data.SaveSMSMessage->Folder = folder;
+		ATGEN_SetSMSLocation(
+			s,
+			s->Phone.Data.SaveSMSMessage,
+			/* We care only about SIM/Phone */
+			s->Phone.Data.SaveSMSMessage->Folder <= 2 ? 1 : 2,
+			s->Phone.Data.SaveSMSMessage->Location
+		);
 		return ERR_NONE;
 	case AT_Reply_Error:
 		smprintf(s, "Error\n");
@@ -1584,7 +1585,7 @@ GSM_Error ATGEN_ReplyAddSMSMessage(GSM_Protocol_Message *msg, GSM_StateMachine *
 	return ERR_UNKNOWNRESPONSE;
 }
 
-GSM_Error ATGEN_MakeSMSFrame(GSM_StateMachine *s, GSM_SMSMessage *message, unsigned char *hexreq, int *current, size_t *length2)
+GSM_Error ATGEN_MakeSMSFrame(GSM_StateMachine *s, GSM_SMSMessage *message, unsigned char *hexreq, size_t hexlength, int *current, size_t *length2)
 {
 	GSM_Error 		error;
 	GSM_Phone_ATGENData 	*Priv = &s->Phone.Data.Priv.ATGEN;
@@ -1708,7 +1709,7 @@ GSM_Error ATGEN_MakeSMSFrame(GSM_StateMachine *s, GSM_SMSMessage *message, unsig
 			/* If not SMS with UDH, it's as normal text */
 			if (message->UDH.Type == UDH_NoUDH) {
 				error = ATGEN_EncodeText(
-					s, message->Text, UnicodeLength(message->Text), hexreq, sizeof(hexreq), length2
+					s, message->Text, UnicodeLength(message->Text), hexreq, hexlength, length2
 				);
 				if (error != ERR_NONE) {
 					return error;
@@ -1783,7 +1784,7 @@ GSM_Error ATGEN_AddSMS(GSM_StateMachine *s, GSM_SMSMessage *sms)
 	}
 
 	/* Format SMS frame */
-	error = ATGEN_MakeSMSFrame(s, sms, hexreq, &current, &length);
+	error = ATGEN_MakeSMSFrame(s, sms, hexreq, sizeof(hexreq), &current, &length);
 
 	if (error != ERR_NONE) {
 		return error;
@@ -1803,7 +1804,7 @@ GSM_Error ATGEN_AddSMS(GSM_StateMachine *s, GSM_SMSMessage *sms)
 			/* No (good and 100% working) support for alphanumeric numbers */
 			if (sms->Number[1]!='+' && (sms->Number[1]<'0' || sms->Number[1]>'9')) {
 				EncodeUnicode(sms->Number,"123",3);
-				error = ATGEN_MakeSMSFrame(s, sms, hexreq, &current, &length);
+				error = ATGEN_MakeSMSFrame(s, sms, hexreq, sizeof(hexreq), &current, &length);
 				if (error != ERR_NONE) return error;
 			}
 		}
@@ -1960,7 +1961,7 @@ GSM_Error ATGEN_SendSMS(GSM_StateMachine *s, GSM_SMSMessage *sms)
 	if (sms->PDU == SMS_Deliver) {
 		sms->PDU = SMS_Submit;
 	}
-	error = ATGEN_MakeSMSFrame(s, sms, hexreq, &current, &length);
+	error = ATGEN_MakeSMSFrame(s, sms, hexreq, sizeof(hexreq), &current, &length);
 
 	if (error != ERR_NONE) {
 		return error;
@@ -2422,6 +2423,7 @@ int *GetRange(GSM_StateMachine *s, const char *buffer)
 		/* Did we parse anything? */
 		if (endptr == chr) {
 			smprintf(s, "Failed to find number in range!\n");
+			free(result);
 			return NULL;
 		}
 		/* Allocate more memory if needed */
@@ -2457,6 +2459,7 @@ int *GetRange(GSM_StateMachine *s, const char *buffer)
 			break;
 		} else if (*chr != ',') {
 			smprintf(s, "Bad character in range: %c\n", *chr);
+			free(result);
 			return NULL;
 		}
 	}
