@@ -751,14 +751,8 @@ GSM_Error GSM_EncodeMultiPartSMS(GSM_Debug_Info *di,
 		break;
 	case SMS_NokiaVCARD10Long:
 		Coding = SMS_Coding_Default_No_Compression;
-		/* is 1 SMS ? 8 = length of ..SCKE2 */
-		if (Length<=GSM_MAX_SMS_CHARS_LENGTH-8) {
-			sprintf(Buffer,"//SCKE2 ");
-			Length = 8;
-		} else {
-			UDH = UDH_NokiaPhonebookLong;
-		}
-		error = GSM_EncodeVCARD(di, Buffer, buffer_size, &Length,Info->Entries[0].Phonebook,TRUE,Nokia_VCard10);
+		UDH = UDH_NokiaPhonebookLong;
+		error = GSM_EncodeVCARD(di, Buffer, buffer_size, &Length, Info->Entries[0].Phonebook, TRUE, Nokia_VCard10);
 		if (error != ERR_NONE) {
 			goto out;
 		}
@@ -766,18 +760,12 @@ GSM_Error GSM_EncodeMultiPartSMS(GSM_Debug_Info *di,
 		EncodeUnicode(Buffer,Buffer2,Length);
 		break;
 	case SMS_NokiaVCARD21Long:
-		error = GSM_EncodeVCARD(di, Buffer, buffer_size, &Length,Info->Entries[0].Phonebook,TRUE,Nokia_VCard21);
+		error = GSM_EncodeVCARD(di, Buffer, buffer_size, &Length, Info->Entries[0].Phonebook, TRUE, Nokia_VCard21);
 		if (error != ERR_NONE) {
 			goto out;
 		}
 		Coding = SMS_Coding_Default_No_Compression;
-		/* Is 1 SMS ? 12 = length of ..SCKL23F4 */
-		if (Length <= GSM_MAX_SMS_CHARS_LENGTH - 12) {
-			sprintf(Buffer,"//SCKL23F4%c%c",13,10);
-			Length = 12;
-		} else {
-			UDH = UDH_NokiaPhonebookLong;
-		}
+		UDH = UDH_NokiaPhonebookLong;
 		memcpy(Buffer2,Buffer,Length);
 		EncodeUnicode(Buffer,Buffer2,Length);
 		break;
