@@ -1,5 +1,5 @@
 /* Copyright (c) 2002-2004 by Marcin Wiacek and Joergen Thomsen */
-/* Copyright (c) 2009 - 2015 Michal Cihar <michal@cihar.com> */
+/* Copyright (c) 2009 - 2017 Michal Cihar <michal@cihar.com> */
 
 #include <string.h>
 #include <signal.h>
@@ -707,6 +707,10 @@ GSM_Error SMSD_ReadConfig(const char *filename, GSM_SMSDConfig *Config, gboolean
 		fullpath[PATH_MAX] = 0;
 	}
 	Config->shm_key = ftok(fullpath, SMSD_SHM_KEY);
+	if (Config->shm_key < 0) {
+		fprintf(stderr, "Failed to generate SHM key!\n");
+		return FALSE;
+	}
 #endif
 #ifdef WIN32
 	if (filename == NULL) {
@@ -1164,7 +1168,9 @@ gboolean SMSD_RunOn(const char *command, GSM_MultiSMSMessage *sms, GSM_SMSDConfi
 
 		/* Close write end of pipe */
 		close(pipefd[1]);
-		fcntl(pipefd[0], F_SETFL, O_NONBLOCK);
+		if (fcntl(pipefd[0], F_SETFL, O_NONBLOCK) != 0) {
+			SMSD_Log(DEBUG_ERROR, Config, "Failed to set nonblocking pipe to child!");
+		}
 
 		i = 0;
 		do {
@@ -1853,7 +1859,8 @@ GSM_Error SMSD_InitSharedMemory(GSM_SMSDConfig *Config, gboolean writable)
 	/* Initial shared memory content */
 	if (writable) {
 		Config->Status->Version = SMSD_SHM_VERSION;
-		strcpy(Config->Status->PhoneID, Config->PhoneID);
+		strncpy(Config->Status->PhoneID, Config->PhoneID, sizeof(Config->Status->PhoneID));
+		Config->Status->PhoneID[sizeof(Config->Status->PhoneID) - 1] = 0;
 		sprintf(Config->Status->Client, "Gammu %s on %s compiler %s",
 			GAMMU_VERSION,
 			GetOS(),
