@@ -1,5 +1,5 @@
 /* (c) 2002-2004 by Marcin Wiacek and Joergen Thomsen */
-/* Copyright (c) 2009 - 2015 Michal Cihar <michal@cihar.com> */
+/* Copyright (c) 2009 - 2017 Michal Cihar <michal@cihar.com> */
 
 #ifndef __core_h_
 #define __core_h_
@@ -15,8 +15,8 @@
 #include "services/sql-core.h"
 #endif
 
-#define SMSD_SHM_KEY (0xface)
 #define SMSD_SHM_VERSION (2)
+#define SMSD_SHM_KEY (0xfa << 16 || SMSD_SHM_VERSION)
 #define SMSD_DB_VERSION (16)
 
 #include "log.h"
