@@ -1,5 +1,5 @@
 /* (c) 2002-2004 by Joergen Thomsen */
-/* Copyright (c) 2009 - 2015 Michal Cihar <michal@cihar.com> */
+/* Copyright (c) 2009 - 2017 Michal Cihar <michal@cihar.com> */
 
 #include <gammu.h>
 
@@ -416,7 +416,13 @@ static GSM_Error SMSDFiles_FindOutboxSMS(GSM_MultiSMSMessage * sms, GSM_SMSDConf
 		} else if (i == 4) {
 			/* OUT<priority>_<phone number>_<serialno>.txt */
 			pos1 = strchr(FileName, '_');
+			if (pos1 == NULL) {
+				return ERR_BUG;
+			}
 			pos2 = strchr(++pos1, '_');
+			if (pos2 == NULL) {
+				return ERR_BUG;
+			}
 			phlen = strlen(pos1) - strlen(pos2);
 		} else {
 			/* something wrong */
@@ -564,7 +570,7 @@ static GSM_Error SMSDFiles_CreateOutboxSMS(GSM_MultiSMSMessage * sms, GSM_SMSDCo
 				1900 + timeinfo->tm_year, timeinfo->tm_mon + 1, timeinfo->tm_mday, timeinfo->tm_hour, timeinfo->tm_min, timeinfo->tm_sec, buffer2, j, ext);
 			strcpy(FullName, Config->outboxpath);
 			strcat(FullName, FileName);
-			fd = open(FileName, O_CREAT | O_EXCL, 0644);
+			fd = open(FullName, O_CREAT | O_EXCL, 0644);
 			if (fd >= 0) {
 				close(fd);
 				break;
